@@ -77,13 +77,11 @@ void Matcher::simd_init_advance_avx512bw()
   }
   else if (pat_->bmd_ == 0)
   {
-#if defined(WITH_STRING_PM)
     if (pat_->min_ >= 4)
       adv_ = &Matcher::simd_advance_string_pmh_avx512bw;
     else if (pat_->min_ > 0)
       adv_ = &Matcher::simd_advance_string_pma_avx512bw;
     else
-#endif
       adv_ = &Matcher::simd_advance_string_avx512bw;
   }
 }
@@ -271,8 +269,6 @@ bool Matcher::simd_advance_string_avx512bw(size_t loc)
   return advance_string(loc);
 }
 
-#if defined(WITH_STRING_PM)
-
 /// Implements AVX512BW string search scheme based on http://0x80.pl/articles/simd-friendly-karp-rabin.html
 bool Matcher::simd_advance_string_pma_avx512bw(size_t loc)
 {
@@ -367,8 +363,6 @@ bool Matcher::simd_advance_string_pmh_avx512bw(size_t loc)
   return advance_string_pmh(loc);
 }
 
-#endif // WITH_STRING_PM
-
 #else
 
 // appease ranlib "has no symbols"
